@@ -214,9 +214,7 @@ class _LayerObj:
                     temp._loader(entry)
                     self.__techniques.append(temp)
                 except MissingParameters as e:
-                    handler(
-                        type(self).__name__, f"Technique {entry} is missing parameters: {e}. Skipping."
-                    )
+                    handler(type(self).__name__, f"Technique {entry} is missing parameters: {e}. Skipping.")
 
     @property
     def gradient(self):
@@ -256,9 +254,7 @@ class _LayerObj:
                     temp = LegendItem(entry["label"], entry["color"])
                     self.__legendItems.append(temp)
                 except MissingParameters as e:
-                    handler(
-                        type(self).__name__, f"Legend Item {entry} is missing parameters: {e}. Skipping."
-                    )
+                    handler(type(self).__name__, f"Legend Item {entry} is missing parameters: {e}. Skipping.")
 
     @property
     def showTacticRowBackground(self):
@@ -352,7 +348,7 @@ class _LayerObj:
                     loadChecker(type(self).__name__, entry.get_dict(), ["divider"], "linkdiv")
                     self.__links.append(entry)
                 elif isinstance(entry, dict):
-                    if "divider" in entry and entry["divider"] == True:
+                    if "divider" in entry and entry["divider"]:
                         loadChecker(type(self).__name__, entry, ["divider"], "linkdiv")
                         self.__links.append(LinkDiv(divider=entry["divider"]))
                     else:
