@@ -134,7 +134,9 @@ class MatrixGen:
         self.convert_data = {}
         self.collections = dict()
         if source.lower() not in ["taxii", "local", "remote", "memorystore"]:
-            logger.error(f"Unable to generate matrix, source {source} is not one of [taxii | remote | local | memorystore]")
+            logger.error(
+                f"Unable to generate matrix, source {source} is not one of [taxii | remote | local | memorystore]"
+            )
             raise ValueError
 
         if source.lower() == "taxii":
@@ -154,7 +156,7 @@ class MatrixGen:
                 else:
                     self.collections["enterprise"] = hd
             else:
-                logger.error(f"source=local specified, but path to local source not provided")
+                logger.error("source=local specified, but path to local source not provided")
                 raise ValueError
 
         elif source.lower() == "remote":
@@ -187,7 +189,7 @@ class MatrixGen:
                 else:
                     self.collections["enterprise"] = resource
             else:
-                logger.error(f"source=memorystore specified, but no data was provided!")
+                logger.error("source=memorystore specified, but no data was provided!")
                 raise ValueError
 
         self.matrix = {}
